* [PATCH 2/7] virtio: rename 'pagesize' arg to vring_init/vring_size
@ 2008-11-12 12:22 Rusty Russell
0 siblings, 0 replies; only message in thread
From: Rusty Russell @ 2008-11-12 12:22 UTC (permalink / raw)
To: linux-kernel; +Cc: Hollis Blanchard, aliguori, markmc, kvm
It's really the alignment desired for consumer/producer separation;
historically this x86 pagesize, but with PowerPC it'll still be x86
pagesize. And in theory lguest could choose a different value.
Signed-off-by: Rusty Russell <rusty@rustcorp.com.au>
---
include/linux/virtio_ring.h | 12 ++++++------
1 file changed, 6 insertions(+), 6 deletions(-)
diff -r c6761450d706 include/linux/virtio_ring.h
--- a/include/linux/virtio_ring.h Wed Nov 12 21:47:57 2008 +1030
+++ b/include/linux/virtio_ring.h Wed Nov 12 21:51:09 2008 +1030
@@ -83,7 +83,7 @@
* __u16 avail_idx;
* __u16 available[num];
*
* // Padding to the next page boundary.
* char pad[];
*
* // A ring of used descriptor heads with free-running index.
@@ -93,19 +93,19 @@
* };
*/
static inline void vring_init(struct vring *vr, unsigned int num, void *p,
- unsigned long pagesize)
+ unsigned long align)
{
vr->num = num;
vr->desc = p;
vr->avail = p + num*sizeof(struct vring_desc);
- vr->used = (void *)(((unsigned long)&vr->avail->ring[num] + pagesize-1)
- & ~(pagesize - 1));
+ vr->used = (void *)(((unsigned long)&vr->avail->ring[num] + align-1)
+ & ~(align - 1));
}
-static inline unsigned vring_size(unsigned int num, unsigned long pagesize)
+static inline unsigned vring_size(unsigned int num, unsigned long align)
{
return ((sizeof(struct vring_desc) * num + sizeof(__u16) * (2 + num)
- + pagesize - 1) & ~(pagesize - 1))
+ + align - 1) & ~(align - 1))
+ sizeof(__u16) * 2 + sizeof(struct vring_used_elem) * num;
}
^ permalink raw reply [flat|nested] only message in thread
only message in thread, other threads:[~2008-11-12 12:22 UTC | newest]
Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2008-11-12 12:22 [PATCH 2/7] virtio: rename 'pagesize' arg to vring_init/vring_size Rusty Russell
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
@@ -83,7 +83,7 @@
* __u16 available[num];
*
- * // Padding to the next page boundary.
+ * // Padding to the next align boundary.
* char pad[];
*